@@ -23,10 +23,9 @@
 #define ADDHOSTDIALOG_H
 
 #include "kdepim_export.h"
-#include <qdialog.h>
+#include <QDialog>
 
-namespace KLDAP
-{
+namespace KLDAP {
 class LdapServer;
 class AddHostDialogPrivate;
 class KDEPIM_EXPORT AddHostDialog : public QDialog
@@ -47,7 +46,6 @@ private Q_SLOTS:
 private:
     AddHostDialogPrivate *const d;
 };
-
 }
 
 #endif // ADDHOSTDIALOG_H
