@@ -48,7 +48,6 @@
 #include <QTimeEdit>
 #include <QButtonGroup>
 #include <QGroupBox>
-#include <QHBoxLayout>
 
 using namespace KPIM;
 
@@ -148,7 +147,7 @@ KPrefsWidInt::KPrefsWidInt(KConfigSkeleton::ItemInt *item, QWidget *parent)
     if (!mItem->maxValue().isNull()) {
         mSpin->setMaximum(mItem->maxValue().toInt());
     }
-    connect(mSpin, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &KPrefsWidInt::changed);
+    connect(mSpin, qOverload<int>(&QSpinBox::valueChanged), this, &KPrefsWidInt::changed);
     mLabel->setBuddy(mSpin);
     QString toolTip = mItem->toolTip();
     if (!toolTip.isEmpty()) {
@@ -434,7 +433,7 @@ KPrefsWidRadios::KPrefsWidRadios(KConfigSkeleton::ItemEnum *item, QWidget *paren
     mBox = new QGroupBox(mItem->label(), parent);
     new QVBoxLayout(mBox);
     mGroup = new QButtonGroup(parent);
-    connect(mGroup, static_cast<void (QButtonGroup::*)(int)>(&QButtonGroup::buttonClicked), this, &KPrefsWidRadios::changed);
+    connect(mGroup, qOverload<int>(&QButtonGroup::buttonClicked), this, &KPrefsWidRadios::changed);
 }
 
 KPrefsWidRadios::~KPrefsWidRadios()
@@ -482,13 +481,20 @@ QList<QWidget *> KPrefsWidRadios::widgets() const
 KPrefsWidCombo::KPrefsWidCombo(KConfigSkeleton::ItemEnum *item, QWidget *parent)
     : mItem(item)
 {
-    QWidget *hbox = new QWidget(parent);
-    QHBoxLayout *hboxHBoxLayout = new QHBoxLayout(hbox);
-    hboxHBoxLayout->setMargin(0);
-    mLabel = new QLabel(mItem->label(), hbox);
-    mCombo = new KComboBox(hbox);
-    hboxHBoxLayout->addWidget(mCombo);
-    connect(mCombo, static_cast<void (KComboBox::*)(int)>(&KComboBox::activated), this, &KPrefsWidCombo::changed);
+    mLabel = new QLabel(mItem->label(), parent);
+    mCombo = new KComboBox(parent);
+    connect(mCombo, qOverload<int>(&KComboBox::activated), this, &KPrefsWidCombo::changed);
+    mLabel->setBuddy(mCombo);
+    QString toolTip = mItem->toolTip();
+    if (!toolTip.isEmpty()) {
+        mLabel->setToolTip(toolTip);
+        mCombo->setToolTip(toolTip);
+    }
+    QString whatsThis = mItem->whatsThis();
+    if (!whatsThis.isEmpty()) {
+        mLabel->setWhatsThis(whatsThis);
+        mCombo->setWhatsThis(whatsThis);
+    }
 }
 
 KPrefsWidCombo::~KPrefsWidCombo()
@@ -793,8 +799,8 @@ void KPrefsDialog::autoCreate()
     for (it = items.constBegin(); it != items.constEnd(); ++it) {
         QString group = (*it)->group();
 
-        QWidget *page;
-        QGridLayout *layout;
+        QWidget *page = nullptr;
+        QGridLayout *layout = nullptr;
         int currentRow;
         if (!mGroupPages.contains(group)) {
             page = new QWidget(this);
