@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2013-2018 Montel Laurent <montel@kde.org>
+    Copyright (c) 2013-2019 Montel Laurent <montel@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -30,9 +30,8 @@ public:
         : labelStr(_label)
         , q(qq)
     {
-        QHBoxLayout *lay = new QHBoxLayout;
-        lay->setMargin(0);
-        q->setLayout(lay);
+        QHBoxLayout *lay = new QHBoxLayout(q);
+        lay->setContentsMargins(0, 0, 0, 0);
         indicator = new ProgressIndicatorWidget;
         lay->addWidget(indicator);
         label = new QLabel;
