@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2017-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2017-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -23,8 +23,6 @@ using namespace KPIM;
 
 AddressessLineEditAbstractPlugin::AddressessLineEditAbstractPlugin(QObject *parent)
     : QObject(parent)
-    , mLinedit(nullptr)
-    , mEnabled(true)
 {
 }
 
